# History

## 0.1.7
- Including jinja2 templates.

## 0.1.6

### Fixed
- Include missing template files 

## 0.1.4
Add initial Task Insights module

## 0.1.3

### Updated
Output directory is now created automatically if it doesn't exist

## 0.1.2

Initial Switch Guides Scaffolder Release